@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponseWriter.h 2273 2006-12-17 13:35:43Z svn $
+ * $Id: ApacheResponseWriter.h 2296 2006-12-24 02:58:57Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_WRITER_H
@@ -41,7 +41,6 @@
 #include "Message.h"
 #include "Macro.h"
 
-using namespace std;
 
 typedef struct request_rec request_rec;
 typedef struct conn_rec conn_rec;
@@ -56,7 +55,7 @@ public:
     ApacheResponseWriter(request_rec *r);
     ApacheResponseWriter(ApacheResponseWriter& writer);
     ~ApacheResponseWriter();
-    void write(const char *str, apr_size_t length) throw()
+    void write(const char *str, apr_size_t length)
     {
         if (UNLIKELY(length == 0)) {
             return;
@@ -70,24 +69,24 @@ public:
             flush();
         }
     };
-    void write(const char *str) throw()
+    void write(const char *str)
     {
         write(str, strlen(str));
     };
-    void write(int i) throw()
+    void write(int i)
     {
         write(apr_itoa(pool_, i));
     };
     void finish();
 
     static int sendfile(request_rec *r, apr_file_t *file, apr_uint64_t length);
-    static bool is_mmap_enabled(request_rec *r) throw();
-    static bool is_sendfile_enabled(request_rec *r) throw();
+    static bool is_mmap_enabled(request_rec *r);
+    static bool is_sendfile_enabled(request_rec *r);
 
 private:
     static const apr_size_t IO_VECTOR_SIZE = RES_IO_VECTOR_SIZE;
 
-    void flush() throw();
+    void flush();
 
     apr_pool_t *pool_;
     conn_rec *connection_;
