@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: File.h 2294 2006-12-23 18:25:41Z svn $
+ * $Id: File.h 2375 2007-02-03 04:55:58Z svn $
  *****************************************************************************/
 
 #ifndef FILE_H
@@ -155,7 +155,7 @@ public:
 
         if (apr_file_open(&file_, file_path_, flag, APR_OS_DEFAULT,
                           pool_) != APR_SUCCESS) {
-            apr_pstrcat(pool_,
+            throw apr_pstrcat(pool_,
                               MESSAGE_FILE_OPEN_FAILED,
                               " [", file_path_, "]",
                               " (" __FILE__ ":" APR_STRINGIFY(__LINE__) ")",
