@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: WriteLocker.h 2366 2007-01-08 07:01:11Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -30,6 +30,7 @@
 
 #include "Environment.h"
 
+#include "apr_time.h"
 #include "apr_global_mutex.h"
 
 #include "ReadWriteLocker.h"
@@ -53,7 +54,9 @@ public:
      * @param[out] read_count 読み出し中のスレッドの数
      */
     WriteLocker(apr_atomic_t *read_count, bool can_nest_read=false)
-      : ReadWriteLocker(read_count)
+      : ReadWriteLocker(read_count),
+        can_nest_read_(can_nest_read),
+        curr_count_(0)
     {
         if (can_nest_read)  {
             lock_nested();
@@ -64,7 +67,7 @@ public:
     };
     ~WriteLocker()
     {
-        (void)apr_atomic_set(read_count_, 0);
+        (void)apr_atomic_set(read_count_, curr_count_);
     };
     static bool is_locked(apr_atomic_t *read_count) {
         return apr_atomic_read(read_count) == ReadWriteLocker::WRITE_LOCKED;
@@ -81,13 +84,13 @@ private:
                 continue;
             }
 
-            if (UNLIKELY(apr_atomic_cas(read_count_, WRITE_LOCKED, curr_count)
-                         != 0)) {
-                yield();
-                continue;
+            if (LIKELY(apr_atomic_cas(read_count_, WRITE_LOCKED, curr_count)
+                       == 0)) {
+                curr_count_ = curr_count;
+                return;
             }
 
-            return;
+            yield();
         }
     };
 
@@ -99,14 +102,16 @@ private:
             }
 
             if (UNLIKELY(apr_atomic_cas(read_count_, WRITE_LOCKED, 0)
-                         != 0)) {
-                yield();
-                continue;
+                         == 0)) {
+                return;
             }
 
-            return;
+            yield();
         }
     };
+
+    bool can_nest_read_;
+    apr_atomic_t curr_count_;
 };
 
 #endif
