@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.h 2220 2006-12-10 06:10:27Z svn $
+ * $Id: uploader_util.h 2272 2006-12-17 10:21:48Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_UTIL_H
@@ -69,7 +69,7 @@ const char *get_dispos_encoding(const char *user_agent);
 template<class R>
 void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
                       const char **file_name, const char **file_mime,
-                      apr_off_t *file_size, const char **file_digest,
+                      apr_uint64_t *file_size, const char **file_digest,
                       const char **file_temp_path, const char **remove_pass,
                       const char **download_pass, const char **comment)
 {
@@ -111,7 +111,7 @@ void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
 template<class R>
 void get_mail_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
                            const char **file_name, const char **file_mime,
-                           apr_off_t *file_size, const char **file_digest,
+                           apr_uint64_t *file_size, const char **file_digest,
                            const char **file_temp_path, const char **remove_pass,
                            const char **download_pass, const char **comment)
 {
