@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Base64FileWriter.cpp 2292 2006-12-23 00:38:56Z svn $
+ * $Id: Base64FileWriter.cpp 2346 2007-01-07 09:32:13Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -34,9 +34,11 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2292 2006-12-23 00:38:56Z svn $");
+SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2346 2007-01-07 09:32:13Z svn $");
 #endif
 
+#define UCHAR(c) static_cast<unsigned char>(c)
+
 template<class W> const unsigned char
 Base64FileWriter<W>::ALPHABET[65] =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
@@ -55,7 +57,7 @@ Base64FileWriter<W>::Base64FileWriter(apr_pool_t *pool, apr_file_t *file,
     memset(alphabet_value_, 0, sizeof(alphabet_value_));
 
     for (apr_size_t i = 0; i < sizeof(ALPHABET); i++) {
-        alphabet_value_[ALPHABET[i]]    = i;
+        alphabet_value_[ALPHABET[i]]    = static_cast<char>(i);
         is_alphabet_[ALPHABET[i]]       = 1;
     }
 }
@@ -78,11 +80,11 @@ void Base64FileWriter<W>::write_impl(unsigned char *buffer,
 
         if (c == '=') {
             if (decode_buffer_index_ == 2) {
-                buffer[write_size+0] = (decode_buffer_ >> 4) & 0xff;
+                buffer[write_size+0] = UCHAR((decode_buffer_ >> 4) & 0xff);
                 write_size += 1;
             } else if (decode_buffer_index_ == 3) {
-                buffer[write_size+0] = (decode_buffer_ >> 10) & 0xff;
-                buffer[write_size+1] = (decode_buffer_ >>  2) & 0xff;
+                buffer[write_size+0] = UCHAR((decode_buffer_ >> 10) & 0xff);
+                buffer[write_size+1] = UCHAR((decode_buffer_ >>  2) & 0xff);
                 write_size += 2;
             }
             break;
@@ -95,9 +97,9 @@ void Base64FileWriter<W>::write_impl(unsigned char *buffer,
         decode_buffer_index_++;
 
         if (decode_buffer_index_ == 4) {
-            buffer[write_size+0] = (decode_buffer_ >> 16) & 0xff;
-            buffer[write_size+1] = (decode_buffer_ >>  8) & 0xff;
-            buffer[write_size+2] = (decode_buffer_ >>  0) & 0xff;
+            buffer[write_size+0] = UCHAR((decode_buffer_ >> 16) & 0xff);
+            buffer[write_size+1] = UCHAR((decode_buffer_ >>  8) & 0xff);
+            buffer[write_size+2] = UCHAR((decode_buffer_ >>  0) & 0xff);
 
             write_size += 3;
 
