@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2332 2006-12-31 02:07:19Z svn $
+ * $Id: DownloadFlowController.cpp 2374 2007-01-23 13:42:21Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2332 2006-12-31 02:07:19Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2374 2007-01-23 13:42:21Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -121,7 +121,7 @@ const char *DownloadFlowController::dump_list(apr_pool_t *pool,
 {
     const char *dump;
 
-    dump = apr_psprintf(pool, "%-24s : %" APR_SIZE_T_FMT  "\n",
+    dump = apr_psprintf(pool, "%-24s : %u\n",
                         "total count", flow_controller->downloader_count_);
     for (apr_size_t i = 0; i < DLD_MAX_SESSION_COUNT; i++) {
         if (flow_controller->downloader_list_[i].session_count == 0) {
@@ -189,9 +189,8 @@ DownloadFlowController::downloader_list_get(apr_sockaddr_t *sockaddr)
 const char *DownloadFlowController::dump_downloader(apr_pool_t *pool,
                                                     downloader_t *downloader)
 {
-    return apr_psprintf(pool, "%24s : %" APR_SIZE_T_FMT "\n",
-                        &(downloader->paddress[1]),
-                        downloader->session_count);
+    return apr_psprintf(pool, "%24s : %u\n",
+                        &(downloader->paddress[1]), downloader->session_count);
 }
 
 
