@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / FileWriter.cpp
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,44 +22,45 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.cpp 1003 2006-03-14 13:52:47Z svn $
+ * $Id: FileWriter.cpp 2047 2006-11-23 18:57:33Z svn $
  *****************************************************************************/
 
+#include "Environment.h"
+
 #include "FileWriter.h"
+#include "File.h"
+#include "SourceInfo.h"
 
-#ifdef DEBUG
-#include <iostream>
-#endif
-
+SOURCE_INFO_ADD("$Id: FileWriter.cpp 2047 2006-11-23 18:57:33Z svn $");
 
 /******************************************************************************
- * public ᥽å
+ * public メソッド
  *****************************************************************************/
-FileWriter::FileWriter(apr_pool_t *pool, apr_file_t *fd)
+FileWriter::FileWriter(apr_pool_t *pool, apr_file_t *file)
     : pool_(pool),
-      fd_(fd),
-      is_closed_(false)
+      file_(new File(pool, file)),
+      write_size_(0)
 {
 
 }
 
 void FileWriter::close()
 {
-    if (is_closed_) {
-        return;
-    }
-
-    apr_file_close(get_fd());
-
-    is_closed_ = true;
+    file_->close();
 }
 
 FileWriter::~FileWriter()
 {
-    close();
+    try {
+        close();
+    } catch(const char *) {
+        // 無視
+    }
+
+    delete file_;
 }
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
