@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2297 2006-12-24 03:13:15Z svn $
+ * $Id: TemplateExecutor.cpp 2368 2007-01-13 09:48:03Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,7 +41,7 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2297 2006-12-24 03:13:15Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2368 2007-01-13 09:48:03Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -165,7 +165,7 @@ void TemplateExecutor<W>::exec_foreach(const node_t *node)
 
     array_var = variables_[node->child.center->id];
 
-#ifdef DEBUG
+#ifndef FASTEST
     if (array_var == NULL) {
         THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
     } else if (UNLIKELY(array_var->type != Variable::ARRAY)) {
@@ -235,7 +235,7 @@ void TemplateExecutor<W>::exec_print_element(const node_t *node)
         var = variables_[node->id];
         goto VAR;
     VAR:
-#ifdef DEBUG
+#ifndef FASTEST
         if (var == NULL) {
             THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
         }
@@ -290,7 +290,7 @@ bool TemplateExecutor<W>::calc_b_val(const node_t *node)
     case Parser::LESS_THAN:
         return calc_i_val(node->child.left) < calc_i_val(node->child.right);
     default:
-#ifdef DEBUG
+#ifndef FASTEST
         THROW(MESSAGE_BUG_FOUND);
 #else
         return false;
@@ -311,7 +311,7 @@ int TemplateExecutor<W>::calc_i_val(const node_t *node)
     switch (node->type) {
     case Parser::IDENTIFIER:            // IDENTIFIER
         var = variables_[node->id];
-#ifdef DEBUG
+#ifndef FASTEST
         if (var == NULL) {
             THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
         }
@@ -345,14 +345,14 @@ int TemplateExecutor<W>::calc_i_val(const node_t *node)
             var = variables_[node->child.right->id];
             is_return_before = false;
         } else {
-#ifdef DEBUG
+#ifndef FASTEST
             THROW(MESSAGE_BUG_FOUND);
 #else
             // ここには来ないはずだけど，コンパイラの警告をなくすため一応
             return 0;
 #endif
         }
-#ifdef DEBUG
+#ifndef FASTEST
         if (var == NULL) {
             THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
         }
@@ -376,7 +376,7 @@ int TemplateExecutor<W>::calc_i_val(const node_t *node)
     case Parser::MINUS:                 // -
         return calc_i_val(node->child.left) - calc_i_val(node->child.right);
     default:
-#ifdef DEBUG
+#ifndef FASTEST
         THROW(MESSAGE_BUG_FOUND);
 #else
         return 0;
@@ -389,7 +389,7 @@ int TemplateExecutor<W>::calc_i_val(const variable_t *var)
 {
     TRACE_FUNC;
 
-#ifdef DEBUG
+#ifndef FASTEST
     if (var->type != Variable::SCALAR) {
         THROW(MESSAGE_TMPL_SCALAR_TYPE_MISMATCH);
     }
@@ -408,7 +408,7 @@ int TemplateExecutor<W>::calc_assign(const node_t *node)
     TRACE_FUNC;
     EXPECT_NODE_MATCH(ASSIGN, MESSAGE_TMPL_ASSIGN_CALC_FAILED);
 
-#ifdef DEBUG
+#ifndef FASTEST
     if (UNLIKELY((node->child.left != NULL) &&
                  (node->child.left->type != Parser::IDENTIFIER))) {
         THROW(MESSAGE_TMPL_ASSIGN_TYPE_MISMATCH);
@@ -440,7 +440,7 @@ int TemplateExecutor<W>::calc_assign_var(const node_t *node)
     left_var = variables_[left_id];
     right_var = get_variable(node->child.right);
 
-#ifdef DEBUG
+#ifndef FASTEST
     if ((left_var != NULL) &&
         (left_var->type != right_var->type)) {
         THROW(MESSAGE_TMPL_ASSIGN_TYPE_MISMATCH);
@@ -472,7 +472,7 @@ int TemplateExecutor<W>::calc_assign_str(const node_t *node)
         left_var = create_str_var(node->child.right->s);
         variables_[left_id] = left_var;
     } else {
-#ifdef DEBUG
+#ifndef FASTEST
         if (left_var->type != Variable::SCALAR) {
             THROW(MESSAGE_TMPL_SCALAR_TYPE_MISMATCH);
         }
@@ -501,7 +501,7 @@ int TemplateExecutor<W>::calc_assign_int(const node_t *node)
 
         return calc_i_val(left_var);
     } else {
-#ifdef DEBUG
+#ifndef FASTEST
         if (left_var->type != Variable::SCALAR) {
             THROW(MESSAGE_TMPL_SCALAR_TYPE_MISMATCH);
         }
@@ -523,7 +523,7 @@ int TemplateExecutor<W>::calc_assign_diff(const node_t *node,
 
     left_var = variables_[node->child.left->id];
 
-#ifdef DEBUG
+#ifndef FASTEST
     if (left_var == NULL) {
         THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
     }
@@ -555,7 +555,7 @@ TemplateExecutor<W>::get_variable(const node_t *node)
         break;
     case Parser::HASH_REF:              // .
         cont_var = variables_[node->child.left->id];
-#ifdef DEBUG
+#ifndef FASTEST
         if (cont_var == NULL) {
             THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
         } else if (cont_var->type != Variable::HASH) {
@@ -567,7 +567,7 @@ TemplateExecutor<W>::get_variable(const node_t *node)
         break;
     case Parser::ARRAY_REF:             // []
         cont_var = variables_[node->child.left->id];
-#ifdef DEBUG
+#ifndef FASTEST
         if (cont_var == NULL) {
             THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
         } else if (cont_var->type != Variable::ARRAY) {
@@ -581,7 +581,7 @@ TemplateExecutor<W>::get_variable(const node_t *node)
 
         } else if (node->child.right->type == Parser::HASH_REF) { // foo[var].baz
             cont_var = cont_var->v + calc_i_val(node->child.right->child.left);
-#ifdef DEBUG
+#ifndef FASTEST
             if (cont_var->type != Variable::HASH) {
                 THROW(MESSAGE_TMPL_HASH_TYPE_MISMATCH);
             }
@@ -594,7 +594,7 @@ TemplateExecutor<W>::get_variable(const node_t *node)
         break;
     }
 
-#ifdef DEBUG
+#ifndef FASTEST
     if (var == NULL) {
         THROW(MESSAGE_TMPL_UNINITIALIZED_VAR_REFERRED);
     }
