@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemRss.cpp 2203 2006-12-09 15:22:12Z svn $
+ * $Id: UploadItemRss.cpp 2309 2006-12-24 10:48:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -36,11 +36,11 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: UploadItemRss.cpp 2203 2006-12-09 15:22:12Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemRss.cpp 2309 2006-12-24 10:48:50Z svn $");
 #endif
 
 template<class W> const char
-UploadItemRss<W>::CONTENT_TYPE[]      = "application/xml";
+UploadItemRss<W>::CONTENT_TYPE[]      = "application/xml; charset=EUC-JP";
 template<class W> const apr_size_t
 UploadItemRss<W>::MAX_TIME_SIZE       = sizeof("0000-00-00T00:00:00+09:00");
 template<class W> const char
@@ -93,15 +93,16 @@ void UploadItemRss<W>::print(apr_pool_t *pool, const char *base_url,
         } while (item_iter->next());
         print("  </rdf:Seq>\n");
         print(" </items>\n");
+        print(" </channel>\n");
 
         item_iter->reset();
 
         do {
             print(pool, base_url, item_iter->get());
         } while (item_iter->next());
+    } else {
+        print(" </channel>\n");
     }
-
-    print(" </channel>\n");
     print("</rdf:RDF>\n");
 }
 
