@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2368 2007-01-13 09:48:03Z svn $
+ * $Id: uploader_handler.cpp 2374 2007-01-23 13:42:21Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2368 2007-01-13 09:48:03Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2374 2007-01-23 13:42:21Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -412,8 +412,7 @@ static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
 
     Response::set_env(r, "uploader_upload", "");
     Response::set_env(r, "uploader_item_id",
-                      apr_psprintf(r->pool,
-                                   "%" APR_SIZE_T_FMT, item_id));
+                      apr_psprintf(r->pool, "%u", item_id));
 
     return redirect<Response>
         (r, o, apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR, NULL));
@@ -739,8 +738,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
 
             Response::set_env(r, "uploader_download", "");
             Response::set_env(r, "uploader_item_id",
-                              apr_psprintf(r->pool,
-                                           "%" APR_SIZE_T_FMT, item_id));
+                              apr_psprintf(r->pool, "%u", item_id));
 
             Response::Writer::sendfile(r, item_file, uitem->get_file_size());
             finish_download(config, Response::get_remote_addr(r));
@@ -811,8 +809,7 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
         } else {
             Response::set_env(r, "uploader_remove", "");
             Response::set_env(r, "uploader_item_id",
-                              apr_psprintf(r->pool,
-                                           "%" APR_SIZE_T_FMT, item_id));
+                              apr_psprintf(r->pool, "%u", item_id));
 
             return redirect<Response>
                 (r, o,
