@@ -4,11 +4,17 @@
 
 use strict;
 
+use File::Basename;
 use Test::More;
+
+BEGIN {
+    push(@INC, dirname($0));
+}
+
 use UploaderTester;
 
 use constant BASE_URL       => 'http://localhost:8080/up/';
-use constant TEST_FILE      => '../data/image.png';
+use constant TEST_FILE      => dirname($0) . '/../data/image.png';
 use constant TEST_COMMENT   => 'test';
 use constant TEST_DL_PASS   => 'D';
 use constant TEST_RM_PASS   => 'R';
